Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/circuitplayground_acceleration.py
    :caption: examples/circuitplayground_acceleration.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_pixels_simpletest.py
    :caption: examples/circuitplayground_pixels_simpletest.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_shake.py
    :caption: examples/circuitplayground_shake.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_tapdetect_single_double.py
    :caption: examples/circuitplayground_tapdetect_single_double.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_tapdetect.py
    :caption: examples/circuitplayground_tapdetect.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_tone.py
    :caption: examples/circuitplayground_tone.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_touch_all.py
    :caption: examples/circuitplayground_touched.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_acceleration_neopixels.py
    :caption: examples/circuitplayground_acceleration_neopixels.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_button_a.py
    :caption: examples/circuitplayground_button_a.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_button_b.py
    :caption: examples/circuitplayground_button_b.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_buttons_1_neopixel.py
    :caption: examples/circuitplayground_buttons_1_neopixel.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_buttons_neopixels.py
    :caption: examples/circuitplayground_buttons_neopixels.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_ir_receive.py
    :caption: examples/circuitplayground_ir_receive.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_ir_transmit.py
    :caption: examples/circuitplayground_ir_transmit.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_light_neopixels.py
    :caption: examples/circuitplayground_light_neopixels.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_light.py
    :caption: examples/circuitplayground_light.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_neopixel_0_1.py
    :caption: examples/circuitplayground_neopixel_0_1.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_light_plotter.py
    :caption: examples/circuitplayground_light_plotter.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_play_file_buttons.py
    :caption: examples/circuitplayground_play_file_buttons.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_play_file.py
    :caption: examples/circuitplayground_play_file.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_play_tone_buttons.py
    :caption: examples/circuitplayground_play_tone_buttons.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_play_tone.py
    :caption: examples/circuitplayground_play_tone.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_red_led_blinky.py
    :caption: examples/circuitplayground_red_led_blinky.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_red_led_blnky_short.py
    :caption: examples/circuitplayground_red_led_blnky_short.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_red_led.py
    :caption: examples/circuitplayground_red_led.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_slide_switch_red_led.py
    :caption: examples/circuitplayground_slide_switch_red_led.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_slide_switch_red_led_short.py
    :caption: examples/circuitplayground_slide_switch_red_led_short.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_slide_switch.py
    :caption: examples/circuitplayground_slide_switch.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_sound_meter.py
    :caption: examples/circuitplayground_sound_meter.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_tap_red_led.py
    :caption: examples/circuitplayground_tap_red_led.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_temperature_neopixels.py
    :caption: examples/circuitplayground_temperature_neopixels.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_temperature_plotter.py
    :caption: examples/circuitplayground_temperature_plotter.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_temperature.py
    :caption: examples/circuitplayground_temperature.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_touch_pixel_fill_rainbow.py
    :caption: examples/circuitplayground_touch_pixel_fill_rainbow.py
    :linenos:

.. literalinclude:: ../examples/circuitplayground_touch_pixel_rainbow.py
    :caption: examples/circuitplayground_touch_pixel_rainbow.py
    :linenos:
